@@ -24,7 +24,7 @@ typedef Eo Efl_Appthread;
  */
 #define EFL_APPTHREAD_CLASS efl_appthread_class_get()
 
-EWAPI const Efl_Class *efl_appthread_class_get(void);
+EWAPI const Efl_Class *efl_appthread_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
