@@ -20,7 +20,7 @@ typedef Eo Efl_Divisor_Interpolator;
  */
 #define EFL_DIVISOR_INTERPOLATOR_CLASS efl_divisor_interpolator_class_get()
 
-EWAPI const Efl_Class *efl_divisor_interpolator_class_get(void);
+EWAPI const Efl_Class *efl_divisor_interpolator_class_get(void) EINA_CONST;
 
 /**
  * @brief Customize divisor factor.
