@@ -65,7 +65,7 @@ typedef enum
  */
 #define EFL_EXE_CLASS efl_exe_class_get()
 
-EWAPI const Efl_Class *efl_exe_class_get(void);
+EWAPI const Efl_Class *efl_exe_class_get(void) EINA_CONST;
 
 /**
  * @brief Send a signal to this process.
