@@ -13,13 +13,14 @@ typedef Eo Ecore_Audio_In_Sndfile;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Ecore Audio sndfile input.
  *
  * @ingroup Ecore_Audio_In_Sndfile
  */
 #define ECORE_AUDIO_IN_SNDFILE_CLASS ecore_audio_in_sndfile_class_get()
 
-EWAPI const Eo_Class *ecore_audio_in_sndfile_class_get(void);
-
+EWAPI const Efl_Class *ecore_audio_in_sndfile_class_get(void) EINA_CONST;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
