@@ -48,7 +48,7 @@ typedef enum
  */
 #define EFL_NET_CONTROL_TECHNOLOGY_CLASS efl_net_control_technology_class_get()
 
-EWAPI const Efl_Class *efl_net_control_technology_class_get(void);
+EWAPI const Efl_Class *efl_net_control_technology_class_get(void) EINA_CONST;
 
 /**
  * @brief If @c true the technology is available. If @c false technology is
