@@ -27,7 +27,7 @@ typedef Eo Efl_Net_Socket;
  */
 #define EFL_NET_SOCKET_INTERFACE efl_net_socket_interface_get()
 
-EWAPI const Efl_Class *efl_net_socket_interface_get(void);
+EWAPI const Efl_Class *efl_net_socket_interface_get(void) EINA_CONST;
 
 #ifdef EFL_NET_SOCKET_PROTECTED
 /**
