@@ -35,7 +35,7 @@ typedef enum
  */
 #define EFL_GFX_BUFFER_INTERFACE efl_gfx_buffer_interface_get()
 
-EWAPI const Efl_Class *efl_gfx_buffer_interface_get(void);
+EWAPI const Efl_Class *efl_gfx_buffer_interface_get(void) EINA_CONST;
 
 /**
  * @brief Rectangular size of the pixel buffer as allocated in memory.
