@@ -28,7 +28,7 @@ typedef Eo Efl_Gfx_Filter;
  */
 #define EFL_GFX_FILTER_INTERFACE efl_gfx_filter_interface_get()
 
-EWAPI const Efl_Class *efl_gfx_filter_interface_get(void);
+EWAPI const Efl_Class *efl_gfx_filter_interface_get(void) EINA_CONST;
 
 /**
  * @brief A graphical filter program on this object.
