@@ -20,10 +20,10 @@ typedef Eo Efl_Gfx_Gradient_Linear;
  */
 #define EFL_GFX_GRADIENT_LINEAR_INTERFACE efl_gfx_gradient_linear_interface_get()
 
-EWAPI const Efl_Class *efl_gfx_gradient_linear_interface_get(void);
+EWAPI const Efl_Class *efl_gfx_gradient_linear_interface_get(void) EINA_CONST;
 
 /**
- * @brief Sets the start point of this linear gradient.
+ * @brief The start point of this linear gradient.
  *
  * @param[in] obj The object.
  * @param[in] x X co-ordinate of start point
@@ -34,7 +34,7 @@ EWAPI const Efl_Class *efl_gfx_gradient_linear_interface_get(void);
 EOAPI void efl_gfx_gradient_linear_start_set(Eo *obj, double x, double y);
 
 /**
- * @brief Gets the start point of this linear gradient.
+ * @brief The start point of this linear gradient.
  *
  * @param[in] obj The object.
  * @param[out] x X co-ordinate of start point
@@ -45,7 +45,7 @@ EOAPI void efl_gfx_gradient_linear_start_set(Eo *obj, double x, double y);
 EOAPI void efl_gfx_gradient_linear_start_get(const Eo *obj, double *x, double *y);
 
 /**
- * @brief Sets the end point of this linear gradient.
+ * @brief The end point of this linear gradient.
  *
  * @param[in] obj The object.
  * @param[in] x X co-ordinate of end point
@@ -56,7 +56,7 @@ EOAPI void efl_gfx_gradient_linear_start_get(const Eo *obj, double *x, double *y
 EOAPI void efl_gfx_gradient_linear_end_set(Eo *obj, double x, double y);
 
 /**
- * @brief Gets the end point of this linear gradient.
+ * @brief The end point of this linear gradient.
  *
  * @param[in] obj The object.
  * @param[out] x X co-ordinate of end point
