@@ -13,12 +13,14 @@ typedef Eo Eldbus_Model_Connection;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Eldbus model connection class
  *
  * @ingroup Eldbus_Model_Connection
  */
 #define ELDBUS_MODEL_CONNECTION_CLASS eldbus_model_connection_class_get()
 
-EWAPI const Efl_Class *eldbus_model_connection_class_get(void);
+EWAPI const Efl_Class *eldbus_model_connection_class_get(void) EINA_CONST;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
