@@ -20,7 +20,7 @@ typedef Eo Eldbus_Model_Proxy;
  */
 #define ELDBUS_MODEL_PROXY_CLASS eldbus_model_proxy_class_get()
 
-EWAPI const Efl_Class *eldbus_model_proxy_class_get(void);
+EWAPI const Efl_Class *eldbus_model_proxy_class_get(void) EINA_CONST;
 
 /**
  * @brief Object
