@@ -42,7 +42,7 @@ typedef Eo Efl_Ui_Collection;
  */
 #define EFL_UI_COLLECTION_CLASS efl_ui_collection_class_get()
 
-EWAPI const Efl_Class *efl_ui_collection_class_get(void);
+EWAPI const Efl_Class *efl_ui_collection_class_get(void) EINA_CONST;
 
 /**
  * @brief Brings the passed item into the viewport.
