@@ -16,7 +16,7 @@ typedef Eo Efl_Ui_Focus_Manager_Sub;
 #ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A class that automatically registers its border elements in the
- * parent manager
+ * parent manager.
  *
  * This sub manager will register its border elements on the parent manager.
  * The parent manager is found with the @ref Efl_Ui_Focus_Object interface of
@@ -33,7 +33,7 @@ typedef Eo Efl_Ui_Focus_Manager_Sub;
  */
 #define EFL_UI_FOCUS_MANAGER_SUB_MIXIN efl_ui_focus_manager_sub_mixin_get()
 
-EWAPI const Efl_Class *efl_ui_focus_manager_sub_mixin_get(void);
+EWAPI const Efl_Class *efl_ui_focus_manager_sub_mixin_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
