@@ -21,7 +21,7 @@ typedef Eo Efl_Ui_List_Placeholder_Item;
  */
 #define EFL_UI_LIST_PLACEHOLDER_ITEM_CLASS efl_ui_list_placeholder_item_class_get()
 
-EWAPI const Efl_Class *efl_ui_list_placeholder_item_class_get(void);
+EWAPI const Efl_Class *efl_ui_list_placeholder_item_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
