@@ -86,7 +86,7 @@ typedef enum
  */
 #define EFL_UI_POPUP_CLASS efl_ui_popup_class_get()
 
-EWAPI const Efl_Class *efl_ui_popup_class_get(void);
+EWAPI const Efl_Class *efl_ui_popup_class_get(void) EINA_CONST;
 
 /**
  * @brief The align property specifies a Popup's current positioning relative
