@@ -16,7 +16,7 @@ typedef Eo Efl_Ui_Spotlight_Icon_Indicator;
 #ifdef EFL_BETA_API_SUPPORT
 #define EFL_UI_SPOTLIGHT_ICON_INDICATOR_CLASS efl_ui_spotlight_icon_indicator_class_get()
 
-EWAPI const Efl_Class *efl_ui_spotlight_icon_indicator_class_get(void);
+EWAPI const Efl_Class *efl_ui_spotlight_icon_indicator_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
