@@ -29,10 +29,12 @@ typedef Eo Efl_Ui_Widget_Part_Shadow;
  * It is also possible to manually specify which @ref Efl_Gfx_Filter program to
  * use.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Widget_Part_Shadow
  */
 #define EFL_UI_WIDGET_PART_SHADOW_CLASS efl_ui_widget_part_shadow_class_get()
 
-EWAPI const Efl_Class *efl_ui_widget_part_shadow_class_get(void);
+EWAPI const Efl_Class *efl_ui_widget_part_shadow_class_get(void) EINA_CONST;
 
 #endif
