@@ -301,7 +301,7 @@
 #include "efl_ui.eot.h"
 typedef Eo Efl_Ui_Focus_Manager;
 
-extern EAPI Eina_Error EFL_UI_THEME_APPLY_ERROR_NONE;
+EAPI extern Eina_Error EFL_UI_THEME_APPLY_ERROR_NONE;
 
 #define _EFL_UI_FOCUS_MANAGER_EO_CLASS_TYPE
 #include "efl_ui_focus_object.eo.h"
@@ -585,6 +585,11 @@ struct _Elm_Widget_Item_Data
    Eina_Hash                     *labels;
    Evas_Object                   *track_obj;
 
+   struct {
+      void (*realized)            (Eo *obj);
+      void (*unrealized)          (Eo *obj);
+   } func;
+
    Eina_Bool                      disabled : 1;
    Eina_Bool                      on_deletion : 1;
    Eina_Bool                      on_translate : 1;
