@@ -45,7 +45,7 @@ typedef struct _Elm_Web_Callback_Proxy_Context Elm_Web_Callback_Proxy_Context;
   ELM_WEB_DATA_GET(o, ptr);                          \
   if (EINA_UNLIKELY(!ptr))                           \
     {                                                \
-       CRI("No widget data for object %p (%s)",      \
+       ERR("No widget data for object %p (%s)",      \
            o, evas_object_type_get(o));              \
        return;                                       \
     }
@@ -54,7 +54,7 @@ typedef struct _Elm_Web_Callback_Proxy_Context Elm_Web_Callback_Proxy_Context;
   ELM_WEB_DATA_GET(o, ptr);                          \
   if (EINA_UNLIKELY(!ptr))                           \
     {                                                \
-       CRI("No widget data for object %p (%s)",      \
+       ERR("No widget data for object %p (%s)",      \
            o, evas_object_type_get(o));              \
        return val;                                   \
     }
