@@ -21,7 +21,7 @@ typedef Eo Efl_Canvas_Pointer;
  */
 #define EFL_CANVAS_POINTER_INTERFACE efl_canvas_pointer_interface_get()
 
-EWAPI const Efl_Class *efl_canvas_pointer_interface_get(void);
+EWAPI const Efl_Class *efl_canvas_pointer_interface_get(void) EINA_CONST;
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
