@@ -20,7 +20,7 @@ typedef Eo Efl_Canvas_Vg_Gradient_Linear;
  */
 #define EFL_CANVAS_VG_GRADIENT_LINEAR_CLASS efl_canvas_vg_gradient_linear_class_get()
 
-EWAPI const Efl_Class *efl_canvas_vg_gradient_linear_class_get(void);
+EWAPI const Efl_Class *efl_canvas_vg_gradient_linear_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
