@@ -13,14 +13,15 @@ typedef Eo Efl_Input_Hold;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /** Event data sent when inputs are put on hold or resumed.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Input_Hold
  */
 #define EFL_INPUT_HOLD_CLASS efl_input_hold_class_get()
 
-EWAPI const Efl_Class *efl_input_hold_class_get(void);
+EWAPI const Efl_Class *efl_input_hold_class_get(void) EINA_CONST;
 
 /**
  * @brief Property to show if inputs are now on hold.
@@ -28,6 +29,8 @@ EWAPI const Efl_Class *efl_input_hold_class_get(void);
  * @param[in] obj The object.
  * @param[in] val @c true if inputs are on hold, @c false otherwise
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Input_Hold
  */
 EOAPI void efl_input_hold_set(Eo *obj, Eina_Bool val);
@@ -39,9 +42,10 @@ EOAPI void efl_input_hold_set(Eo *obj, Eina_Bool val);
  *
  * @return @c true if inputs are on hold, @c false otherwise
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Input_Hold
  */
 EOAPI Eina_Bool efl_input_hold_get(const Eo *obj);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
