@@ -27,7 +27,7 @@ typedef Eo Efl_Canvas_Gesture_Long_Press;
  */
 #define EFL_CANVAS_GESTURE_LONG_PRESS_CLASS efl_canvas_gesture_long_press_class_get()
 
-EWAPI const Efl_Class *efl_canvas_gesture_long_press_class_get(void);
+EWAPI const Efl_Class *efl_canvas_gesture_long_press_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
