@@ -22,7 +22,7 @@ typedef Eo Efl_Canvas_Gesture_Recognizer_Long_Press;
  */
 #define EFL_CANVAS_GESTURE_RECOGNIZER_LONG_PRESS_CLASS efl_canvas_gesture_recognizer_long_press_class_get()
 
-EWAPI const Efl_Class *efl_canvas_gesture_recognizer_long_press_class_get(void);
+EWAPI const Efl_Class *efl_canvas_gesture_recognizer_long_press_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
