@@ -22,7 +22,7 @@ typedef Eo Efl_Canvas_Gesture_Recognizer_Triple_Tap;
  */
 #define EFL_CANVAS_GESTURE_RECOGNIZER_TRIPLE_TAP_CLASS efl_canvas_gesture_recognizer_triple_tap_class_get()
 
-EWAPI const Efl_Class *efl_canvas_gesture_recognizer_triple_tap_class_get(void);
+EWAPI const Efl_Class *efl_canvas_gesture_recognizer_triple_tap_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
